@@ -11,8 +11,6 @@ require "async"
 require "async/notification"
 require "async/semaphore"
 
-require "traces"
-
 module Async
 	module Pool
 		# A resource pool controller.
@@ -161,6 +159,7 @@ module Async
 				retire(resource) unless processed
 			end
 			
+			# Drain the pool, closing all resources.
 			def drain
 				Console.debug(self, "Draining pool...", size: @resources.size)
 				
@@ -170,7 +169,7 @@ module Async
 				end
 			end
 			
-			# Close all resources in the pool.
+			# Drain the pool, clear all resources, and stop the gardener.
 			def close
 				self.drain
 				
@@ -324,11 +323,7 @@ module Async
 			def available_resource
 				resource = nil
 				
-				Console.debug(self, "Acquiring concurrency guard...", blocking: @guard.blocking?)
-				
 				@guard.acquire do
-					Console.debug(self, "Acquired concurrency guard.")
-					
 					resource = acquire_or_create_resource
 				end
 				
@@ -385,59 +380,6 @@ module Async
 					return create_resource
 				end
 			end
-			
-			Traces::Provider(self) do
-				def create_resource(...)
-					attributes = {
-						concurrency: @guard.limit,
-					}
-					
-					attributes.merge!(@tags) if @tags
-					
-					Traces.trace('async.pool.create', attributes: attributes) {super}
-				end
-				
-				def drain(...)
-					attributes = {
-						size: @resources.size,
-					}
-					
-					attributes.merge!(@tags) if @tags
-					
-					Traces.trace('async.pool.drain', attributes: attributes) {super}
-				end
-				
-				def acquire(...)
-					attributes = {
-						size: @resources.size,
-						limit: @limit,
-					}
-					
-					attributes.merge!(@tags) if @tags
-					
-					Traces.trace('async.pool.acquire', attributes: attributes) {super}
-				end
-				
-				def release(...)
-					attributes = {
-						size: @resources.size,
-					}
-					
-					attributes.merge!(@tags) if @tags
-					
-					Traces.trace('async.pool.release', attributes: attributes) {super}
-				end
-				
-				def retire(...)
-					attributes = {
-						size: @resources.size,
-					}
-					
-					attributes.merge!(@tags) if @tags
-					
-					Traces.trace('async.pool.retire', attributes: attributes) {super}
-				end
-			end
 		end
 	end
 end
